@@ -14,6 +14,9 @@ def get_path(object, path, resource_path="resources") -> pathlib.Path:
     o = lambda: None
     path = resources.get_resource_path(o, 'icon.png')
     print(path) # ...\current_path\\resources\icon.png
+
+    # Path -> str
+    path_s = str(path)
     ```
     """
     return pathlib.Path(inspect.getfile(object)).parent.joinpath(resource_path).joinpath(path).absolute()
\ No newline at end of file
